@@ -611,7 +611,7 @@ my_array = [
 ]
 "#;
 
-let expected = r#"
+    let expected = r#"
 my_array = [
     [
         [
@@ -636,7 +636,6 @@ my_array = [
     assert_format!(expected, &formatted);
 }
 
-
 #[test]
 fn array_max_new_lines() {
     let src = r#"
@@ -662,7 +661,7 @@ my_array = [
 ]
 "#;
 
-let expected = r#"
+    let expected = r#"
 my_array = [
     [
         [
@@ -903,4 +902,55 @@ fn table_entries_no_blank_space_indent_entries_and_tables() {
     );
 
     assert_format!(src, &formatted);
-}
\ No newline at end of file
+}
+
+#[test]
+fn single_comment_in_array() {
+    let src = r#"
+runtime-benchmarks = [
+    # a comment
+]
+"#;
+
+    let formatted = crate::formatter::format(
+        src,
+        formatter::Options {
+            indent_entries: true,
+            indent_tables: true,
+            indent_string: "    ".into(),
+            ..Default::default()
+        },
+    );
+
+    assert_format!(src, &formatted);
+}
+
+#[test]
+fn table_indents() {
+    let src = r#"
+[[table]]
+    name = "Root Table 1"
+    [table.nestedtable]
+        name = "Nested parent"
+        [[table.nestedtable.subtable]]
+            name = "Subtable 1"
+        [[table.nestedtable.subtable]]
+            name = "Subtable 2"
+
+[[table]]
+    name = "Root Table 2"
+"#;
+
+    let formatted = crate::formatter::format(
+        src,
+        formatter::Options {
+            indent_entries: true,
+            indent_tables: true,
+            indent_string: "    ".into(),
+            ..Default::default()
+        },
+    );
+
+    assert_format!(src, &formatted);
+}
+
